@@ -280,6 +280,8 @@ EVENT_FAX_MAX = 8999
 
 EVENT_CUPS_QUEUES_CHANGED = 9000 # sent by hp-setup if queues added (or removed)
 
+EVENT_MAX_EVENT = 9999
+
 # end of events
 
 
@@ -579,6 +581,7 @@ STATUS_TYPE_LJ = 3
 STATUS_TYPE_LJ_XML = 6
 #STATUS_TYPE_S_LIDIL = 7 # DEPRECATED
 STATUS_TYPE_PJL = 8
+STATUS_TYPE_PML_AND_PJL = 9 # Same as types 3(tbx)+8(hp:)
 
 # status-battery-check-types
 STATUS_BATTERY_CHECK_NONE = 0
@@ -608,6 +611,7 @@ FAX_TYPE_NONE = 0
 FAX_TYPE_BLACK_SEND_EARLY_OPEN = 1 # newer models
 FAX_TYPE_BLACK_SEND_LATE_OPEN = 2 # older models
 FAX_TYPE_BLACK_AND_COLOR_SEND = 3 # future
+FAX_TYPE_SOAP = 4
 
 # pcard-types
 PCARD_TYPE_NONE = 0
@@ -709,3 +713,9 @@ PQ_DIAG_TYPE_NONE = 0
 PQ_DIAG_TYPE_1 = 1
 PQ_DIAG_TYPE_2 = 2
 
+# line feed cal
+LINEFEED_CAL_TYPE_NONE = 0
+LINEFEED_CAL_TYPE_OJ_K550 = 1
+LINEFEED_CAL_TYPE_OJ_PRO_L7XXX = 2
+
+
