@@ -174,7 +174,7 @@ def parseSStatus(s, z=''):
 
         if pen_data_size == 4:
             pen['type'] = REVISION_2_TYPE_MAP.get(int((info & 0xf000L) >> 12L), 0)
-            
+
             if index < (num_pens / 2):
                 pen['kind'] = AGENT_KIND_HEAD
             else:
@@ -553,7 +553,7 @@ def StatusType3( dev, parsedID ): # LaserJet Status (PML/SNMP)
                 agent_health = AGENT_HEALTH_OK
 
         agent_level = int(agent_level/agent_max * 100)
-        
+
         log.debug("agent%d: kind=%d, type=%d, health=%d, level=%d, level-trigger=%d" % \
             (x, agent_kind, agent_type, agent_health, agent_level, agent_trigger))
 
@@ -565,7 +565,7 @@ def StatusType3( dev, parsedID ): # LaserJet Status (PML/SNMP)
                        'level-trigger' : agent_trigger,})
 
         x += 1
-        
+
         if x > 20:
             break
 
@@ -1053,7 +1053,7 @@ def StatusType6(dev): #  LaserJet Status (XML)
            }     
 
 # PJL status codes
-TYPE8_STATUS_CODE_MAP = {
+PJL_STATUS_MAP = {
     10001: STATUS_PRINTER_IDLE, # online
     10002: STATUS_PRINTER_OFFLINE, # offline
     10003: STATUS_PRINTER_WARMING_UP,
@@ -1149,11 +1149,92 @@ TYPE8_STATUS_CODE_MAP = {
     # 44xyy - LJ 4xxx/5xxx paper jam messages
     # 50xxx - Hardware errors
     # 55xxx - Personality errors
-    
+
 }
 
+MIN_PJL_ERROR_CODE = 10001
+DEFAULT_PJL_ERROR_CODE = 10001
+
+def MapPJLErrorCode(error_code, str_code=None):
+    if error_code < MIN_PJL_ERROR_CODE:
+        return STATUS_PRINTER_BUSY
+
+    if str_code is None:
+        str_code = str(error_code)
+        
+    if len(str_code) < 5:
+        return STATUS_PRINTER_BUSY
+
+    status_code = PJL_STATUS_MAP.get(error_code, None)
+
+    if status_code is None:
+        status_code = STATUS_PRINTER_BUSY
+
+        if 10999 < error_code < 12000: # 11xyy - Background paper-loading
+            # x = tray #
+            # yy = media code
+            tray = int(str_code[2])
+            media = int(str_code[3:])
+            log.debug("Background paper loading for tray #%d" % tray)
+            log.debug("Media code = %d" % media)
+
+        elif 11999 < error_code < 13000: # 12xyy - Background paper-tray status
+            # x = tray #
+            # yy = status code
+            tray = int(str_code[2])
+            status = int(str_code[3:])
+            log.debug("Background paper tray status for tray #%d" % tray)
+            log.debug("Status code = %d" % status)
+
+        elif 14999 < error_code < 16000: # 15xxy - Output-bin status
+            # xx = output bin
+            # y = status code
+            bin = int(str_code[2:4])
+            status = int(str_code[4])
+            log.debug("Output bin full for bin #%d" % bin)
+            status_code = STATUS_PRINTER_OUTPUT_BIN_FULL
+
+        elif 19999 < error_code < 28000: # 20xxx, 25xxx, 27xxx PJL errors
+            status_code = STATUS_PRINTER_SERVICE_REQUEST
+
+        elif 29999 < error_code < 31000: # 30xxx - Auto continuable conditions
+            log.debug("Auto continuation condition #%d" % error_code)
+            status_code = STATUS_PRINTER_BUSY
+
+        elif 34999 < error_code < 36000: # 35xxx - Potential operator intervention conditions
+            status_code = STATUS_PRINTER_SERVICE_REQUEST
+
+        elif 39999 < error_code < 41000: # 40xxx - Operator intervention conditions
+            status_code = STATUS_PRINTER_SERVICE_REQUEST
+
+        elif 40999 < error_code < 42000: # 41xyy - Foreground paper-loading messages
+            # x = tray
+            # yy = media code
+            tray = int(str_code[2])
+            media = int(str_code[3:])
+            log.debug("Foreground paper loading for tray #%d" % tray)
+            log.debug("Media code = %d" % media)
+            status_code = STATUS_PRINTER_OUT_OF_PAPER
+
+        elif 41999 < error_code < 43000:
+            status_code = STATUS_PRINTER_MEDIA_JAM
+
+        elif 42999 < error_code < 44000: # 43xyy - Optional paper handling device messages
+            status_code = STATUS_PRINTER_SERVICE_REQUEST
+
+        elif 43999 < error_code < 45000: # 44xyy - LJ 4xxx/5xxx paper jam messages
+            status_code = STATUS_PRINTER_MEDIA_JAM
+
+        elif 49999 < error_code < 51000: # 50xxx - Hardware errors
+            status_code = STATUS_PRINTER_HARD_ERROR
+
+        elif 54999 < error_code < 56000 : # 55xxx - Personality errors
+            status_code = STATUS_PRINTER_HARD_ERROR
+
+    log.debug("Mapped PJL error code %d to status code %d" % (error_code, status_code))
+    return status_code
+
 
-           
 pjl_code_pat = re.compile("""^CODE\s*=\s*(\d.*)$""", re.IGNORECASE)
 
 def StatusType8(dev): #  LaserJet PJL
@@ -1161,133 +1242,69 @@ def StatusType8(dev): #  LaserJet PJL
         dev.openPrint()
     except Error, e:
         log.warn(e.msg)
-        
+
     dev.writePrint("\x1b%-12345X@PJL INFO STATUS \r\n\x1b%-12345X")
     pjl_return = dev.readPrint(1024, timeout=5, allow_short_read=True)
     dev.close()
 
     log.debug_block("PJL return:", pjl_return)
-    
-    code = '10001'
-    
+
+    str_code = '10001'
+
     for line in pjl_return.splitlines():
         line = line.strip()
         match = pjl_code_pat.match(line)
-        
+
         if match is not None:
-            code = match.group(1)
+            str_code = match.group(1)
             break
-    
-    log.debug("Code = %s" % code)
-    
+
+    log.debug("Code = %s" % str_code)
+
     try:
-        error_code = int(code)
+        error_code = int(str_code)
     except ValueError:
-        error_code = 10001
-        
+        error_code = DEFAULT_PJL_ERROR_CODE
+
     log.debug("Error code = %d" % error_code)
-        
-    status_code = TYPE8_STATUS_CODE_MAP.get(error_code, None)
-    
-    if status_code is None:
-        status_code = STATUS_PRINTER_BUSY
-        
-        if 10999 < error_code < 12000: # 11xyy - Background paper-loading
-            # x = tray #
-            # yy = media code
-            tray = int(code[2])
-            media = int(code[3:])
-            log.debug("Background paper loading for tray #%d" % tray)
-            log.debug("Media code = %d" % media)
-            
-        elif 11999 < error_code < 13000: # 12xyy - Background paper-tray status
-            # x = tray #
-            # yy = status code
-            tray = int(code[2])
-            status = int(code[3:])
-            log.debug("Background paper tray status for tray #%d" % tray)
-            log.debug("Status code = %d" % status)
-            
-        elif 14999 < error_code < 16000: # 15xxy - Output-bin status
-            # xx = output bin
-            # y = status code
-            bin = int(code[2:4])
-            status = int(code[4])
-            log.debug("Output bin full for bin #%d" % bin)
-            status_code = STATUS_PRINTER_OUTPUT_BIN_FULL
-            
-        elif 19999 < error_code < 28000: # 20xxx, 25xxx, 27xxx PJL errors
-            status_code = STATUS_PRINTER_SERVICE_REQUEST
-            
-        elif 29999 < error_code < 31000: # 30xxx - Auto continuable conditions
-            log.debug("Auto continuation condition #%d" % error_code)
-            
-        elif 34999 < error_code < 36000: # 35xxx - Potential operator intervention conditions
-            status_code = STATUS_PRINTER_SERVICE_REQUEST
-            
-        elif 39999 < error_code < 41000: # 40xxx - Operator intervention conditions
-            status_code = STATUS_PRINTER_SERVICE_REQUEST
-            
-        elif 40999 < error_code < 42000: # 41xyy - Foreground paper-loading messages
-            # x = tray
-            # yy = media code
-            tray = int(code[2])
-            media = int(code[3:])
-            log.debug("Foreground paper loading for tray #%d" % tray)
-            log.debug("Media code = %d" % media)
-            status_code = STATUS_PRINTER_OUT_OF_PAPER
-            
-        elif 41999 < error_code < 43000:
-            status_code = STATUS_PRINTER_MEDIA_JAM
-        
-        elif 42999 < error_code < 44000: # 43xyy - Optional paper handling device messages
-            status_code = STATUS_PRINTER_SERVICE_REQUEST
-            
-        elif 43999 < error_code < 45000: # 44xyy - LJ 4xxx/5xxx paper jam messages
-            status_code = STATUS_PRINTER_MEDIA_JAM
-            
-        elif 49999 < error_code < 51000: # 50xxx - Hardware errors
-            status_code = STATUS_PRINTER_HARD_ERROR
-            
-        elif 54999 < error_code < 56000 : # 55xxx - Personality errors
-            status_code = STATUS_PRINTER_HARD_ERROR
-            
-        
+
+    status_code = MapPJLErrorCode(error_code, str_code)
+
     agents = []
-    
+
     # TODO: Only handles mono lasers...
     if status_code in (STATUS_PRINTER_LOW_TONER, STATUS_PRINTER_LOW_BLACK_TONER):
         health = AGENT_HEALTH_OK
         level_trigger = AGENT_LEVEL_TRIGGER_ALMOST_DEFINITELY_OUT
         level = 0
-        
+
     elif status_code == STATUS_PRINTER_NO_TONER:
         health = AGENT_HEALTH_MISINSTALLED
         level_trigger = AGENT_LEVEL_TRIGGER_ALMOST_DEFINITELY_OUT
         level = 0
-        
+
     else:
         health = AGENT_HEALTH_OK
         level_trigger = AGENT_LEVEL_TRIGGER_SUFFICIENT_0
         level = 100
-        
+
     log.debug("Agent: health=%d, level=%d, trigger=%d" % (health, level, level_trigger))
-        
-    
+
+
     agents.append({  'kind' : AGENT_KIND_TONER_CARTRIDGE,
                      'type' : AGENT_TYPE_BLACK,
                      'health' : health,
                      'level' : level,
                      'level-trigger' : level_trigger,
                   })
-    
+
     if status_code == 40021:
         top_door = 0
     else:
         top_door = 1
-        
+
     log.debug("Status code = %d" % status_code)
-    
+
     return { 'revision' :    STATUS_REV_UNKNOWN,
              'agents' :      agents,
              'top-door' :    top_door,
@@ -1299,7 +1316,7 @@ def StatusType8(dev): #  LaserJet PJL
              'media-path' :  1,
              'status-code' : status_code,
            }     
-    
+
 
 
 
